@@ -36,10 +36,19 @@ class MediaWikiCluster(object):
         self.networkName=networkName
         self.apps={}
                 
-    def start(self,forceRebuild:bool=False,withInitDB=True):
+    def start(self,forceRebuild:bool=False,withInitDB=True)->int:
         '''
         create and start the composer applications
+        
+        Returns:
+            int: exitCode - 0 if ok 1 if failed
         '''           
+        errMsg=DockerApplication.check()
+        if errMsg is not None:
+            print(errMsg,file=sys.stderr)
+            return 1
+            
+        
         for i,version in enumerate(self.versions):
             mwApp=self.getDockerApplication(i,version)
             mwApp.generateAll()
@@ -50,6 +59,7 @@ class MediaWikiCluster(object):
                     print("Initializing MediaWiki SQL tables")
                 if mwApp.checkDBConnection():
                     mwApp.execute("/tmp/initdb.sh")
+        return 0
             
     def close(self):
         for mwApp in self.apps.values():
@@ -79,9 +89,9 @@ class MediaWikiCluster(object):
             mwApp=self.getDockerApplication(i,version)
             mwApp.generateAll()
 
-__version__ = "0.0.1"
+__version__ = "0.0.7"
 __date__ = '2021-06-21'
-__updated__ = '2021-06-21'
+__updated__ = '2021-06-22'
 DEBUG=False
 
 def main(argv=None): # IGNORE:C0111
@@ -94,13 +104,13 @@ def main(argv=None): # IGNORE:C0111
     program_version = "v%s" % __version__
     program_build_date = str(__updated__)
     program_version_message = '%%(prog)s %s (%s)' % (program_version, program_build_date)
-    program_shortdesc = "wikipush"
+    program_shortdesc = "mwcluster"
     user_name="Wolfgang Fahl"
 
     program_license = '''%s
 
   Created by %s on %s.
-  Copyright 2020 Wolfgang Fahl. All rights reserved.
+  Copyright 2021 Wolfgang Fahl. All rights reserved.
 
   Licensed under the Apache License 2.0
   http://www.apache.org/licenses/LICENSE-2.0
@@ -110,14 +120,15 @@ def main(argv=None): # IGNORE:C0111
 
 ''' % (program_shortdesc,user_name, str(__date__))
     try:
-        forceRebuild=False
         # Setup argument parser
         parser = ArgumentParser(description=program_license, formatter_class=RawDescriptionHelpFormatter)
         parser.add_argument("-d", "--debug", dest="debug",   action="store_true", help="set debug level [default: %(default)s]")
         parser.add_argument('-V', '--version', action='version', version=program_version_message)
         parser.add_argument("-f", "--forceRebuild", dest="forceRebuild",   action="store_true", help="shall the applications rebuild be forced (with stop and remove of existing containers)")
-        mwCluster=MediaWikiCluster()
-        mwCluster.start(forceRebuild)
+        args = parser.parse_args(argv)
+        # create a MediaWiki Cluster
+        mwCluster=MediaWikiCluster(debug=args.debug)
+        return mwCluster.start(forceRebuild=args.forceRebuild)
     except KeyboardInterrupt:
         ### handle keyboard interrupt ###
         return 1
